@@ -52,7 +52,7 @@ class NetworkApiMixin(object):
             options (dict): Driver options as a key-value dictionary
             ipam (IPAMConfig): Optional custom IP scheme for the network.
             check_duplicate (bool): Request daemon to check for networks with
-                same name. Default: ``True``.
+                same name. Default: ``None``.
             internal (bool): Restrict external access to the network. Default
                 ``False``.
             labels (dict): Map of labels to set on the network. Default
@@ -200,7 +200,7 @@ class NetworkApiMixin(object):
         res = self._get(url, params=params)
         return self._result(res, json=True)
 
-    @check_resource('image')
+    @check_resource('container')
     @minimum_version('1.21')
     def connect_container_to_network(self, container, net_id,
                                      ipv4_address=None, ipv6_address=None,
@@ -237,7 +237,7 @@ class NetworkApiMixin(object):
         res = self._post_json(url, data=data)
         self._raise_for_status(res)
 
-    @check_resource('image')
+    @check_resource('container')
     @minimum_version('1.21')
     def disconnect_container_from_network(self, container, net_id,
                                           force=False):
